(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     64270,       2262]
NotebookOptionsPosition[     51533,       1814]
NotebookOutlinePosition[     52130,       1837]
CellTagsIndexPosition[     52087,       1834]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Model of Two-Wire Simple Pendulum with Blades", "Section",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Version history", "Subsection",
 InitializationCell->True],

Cell["\<\
modelversion = 5.1; modelcomment = \"Two-wire simple pendulum with blades\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.482519174358905*^9, 3.48251917611861*^9}, 
   3.4825198123722153`*^9}],

Cell["\<\
modelversion::usage = \"modelversion is a number specifying the version of \
the default model.\"; 
modelcomment::usage = \"modelcomment is a string describing the default \
model.\";\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell["12/3/06 - v3.0: Initial release based on twowiresimple v3.0", "Text",
 InitializationCell->True,
 CellChangeTimes->{3.4825189994387817`*^9}],

Cell["\<\
5/10/10 - v5.1: Graphics update for Mathematica v6/7. Renamed attachments to \
enforce +y=left.\
\>", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.4825189994387817`*^9, 3.482519025731921*^9}, {
  3.4825190945588703`*^9, 3.4825192118628407`*^9}, {3.482519777314641*^9, 
  3.4825198097322683`*^9}, {3.483182393559*^9, 3.483182449605*^9}}],

Cell["\<\
5/18/10 - v5 .1 mine :\tCOM definition changed to COM = {COMx, COMy, COMz} to \
allow for overrides.
\t\t\t\"dpitch\" coherently defined as distance between wire break-off and \
local coordinate origin
\t\t\t\"gravlist\" redefined to account for off-center COM
\t\t\tcomments added/corrected for coherency\
\>", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.483277068401*^9, 3.4832771106689997`*^9}, {
   3.4832861872209997`*^9, 3.483286215611*^9}, {3.4832863289449997`*^9, 
   3.483286346505*^9}, 3.4833583692037973`*^9}],

Cell[CellGroupData[{

Cell["Instructions", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Installation", "Subsubsection",
 InitializationCell->True],

Cell[TextData[{
 "1. Install this notebook (ASUS4ModelDefn.nb) and the matching .m file \
(ASUS4ModelDefn.m) in a convenient directory.\n2. Make sure the files ",
 StyleBox["IFOModel.m",
  FontFamily->"Courier"],
 ", ",
 StyleBox["IFOModel.nb",
  FontFamily->"Courier"],
 ", ",
 StyleBox["wirefunctions.m",
  FontFamily->"Courier"],
 " and ",
 StyleBox["wireanalysis.nb",
  FontFamily->"Courier"],
 " are in the same directory as this notebook.\n3. Make sure the files ",
 StyleBox["RotationsXYZ.nb",
  FontFamily->"Courier"],
 ", ",
 StyleBox["RotationsXYZ.m",
  FontFamily->"Courier"],
 ", ",
 StyleBox["MyShapes.nb",
  FontFamily->"Courier"],
 " and ",
 StyleBox["MyShapes.m",
  FontFamily->"Courier"],
 " are either in your directory for custom packages (if you have one) or in \
the same directory as this notebook.\n4. Make sure the directory ",
 StyleBox["default",
  FontFamily->"Courier"],
 " is installed in the same directory as this notebook. In turn, ",
 StyleBox["default",
  FontFamily->"Courier"],
 " should contain the notebook ",
 StyleBox["ASUS4ModelCalc.nb",
  FontFamily->"Courier"],
 " and a ",
 StyleBox["precomputed",
  FontFamily->"Courier"],
 " subdirectory with lots of saved results.\n5. Open ",
 StyleBox[".../default/ASUS4ModelCalc.nb",
  FontFamily->"Courier"],
 " and follow the instructions there."
}], "Text",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Usage", "Subsubsection",
 InitializationCell->True],

Cell[TextData[{
 "1. This notebook contains only definitions and setup and does no \
non-trivial calculations.\n2. It is set up as a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " autosave package, so that whenever it is saved, the matching .m file is \
automatically updated to match. If you need to change anything, make the \
changes to this file. \n3. There is a line in the model calculation file, ",
 StyleBox["ASUS4ModelCalc.nb",
  FontFamily->"Courier"],
 ", to read in the definitions from the .m file when needed. \n4. All cells \
in this file are initialization cells. If you add any new cells, be sure to \
set the initialization cell attribute. \n5. All interesting symbols have \
::usage tags defined for them, so once the definitions have been loaded you \
can get help on them with the ? operator. For example to get information on \
wirelist, type ?wirelist into an empty cell and evaluate it. You can also use \
?? to get the full definition of a symbol but do this with caution because \
some of the definitions are so long as to cause the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " front end to choke."
}], "Text",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Disable spell-checking. There are so many variables with similar names that \
it's useless.\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{
   RowBox[{"General", "::", "spell"}], ",", 
   RowBox[{"General", "::", "spell1"}]}], "]"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dependencies", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Standard packages", "Text"],

Cell[CellGroupData[{

Cell["Standard packages for use in plotting eigenmodes", "Text",
 InitializationCell->True],

Cell["If[$VersionNumber<6., Needs[\"Graphics`Graphics`\"]]", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837375508451*^9, 3.388837394354858*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["If[$VersionNumber<6., Needs[\"Graphics`Shapes`\"]];", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837375508451*^9, 3.388837394354858*^9}, {
  3.388856501574243*^9, 3.3888566481548977`*^9}, {3.388861247010874*^9, 
  3.38886127843696*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["If[$VersionNumber<6., Needs[\"Graphics`Polyhedra`\"]]", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837400609071*^9, 3.388837404849434*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Standard package useful for pasting together state-space matrices\
\>", "Text",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell["\<\
If[$VersionNumber < 6, Needs[\"LinearAlgebra`MatrixManipulation`\"]] \
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837423685124*^9, 3.388837426298386*^9}, 
   3.388838090102798*^9, 3.3888414561152163`*^9, {3.4647053232870693`*^9, 
   3.464705326900731*^9}}],

Cell[CellGroupData[{

Cell["Custom Packages", "Text"],

Cell[CellGroupData[{

Cell["\<\
Custom rotation matrices in terms of yaw, pitch and roll angles\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<RotationsXYZ`\>\"", "]"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions to display status in window", "Text",
 InitializationCell->True],

Cell["Needs[\"StatusWindow`\"];", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions to export in Matlab .m format", "Text",
 InitializationCell->True],

Cell["Needs[\"MatlabExport`\"];", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters from Bench", "Text",
 InitializationCell->True],

Cell["Needs[\"IFOModel`\"];", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The toolkit", "Text",
 InitializationCell->True],

Cell["Needs[\"PendUtil`\"];", "Input",
 InitializationCell->True],

Cell["\<\
If[utilitiesversion>=3.0,Null, Print[\"Incorrect utilities \
version\"];Abort[],Print[\"Utilities failed to load\"];Abort[]];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3909032575389347`*^9, 3.39090325851551*^9}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The model proper", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Variables and parameters", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
The \"variables\" that specify the state of the system for the purposes of \
the normal mode calculation. This list should not include \"parameters\" such \
as displacement variables for the support structure which only vary for the \
purposes of perturbation and transfer function calculations.\
\>", "Text",
 InitializationCell->True],

Cell["\<\
allvars::usage = \"allvars is part of the specification of the model. It \
should be a list of the position and angle variables for the system. It \
shouldn't include velocities, or the coordinates of the support structure.\";\
\
\>", "Input",
 InitializationCell->True],

Cell["\<\
allvars = {
\tx0,y0,z0,yaw0,pitch0,roll0
};\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
The \"floats\" that specify the position and angle variables for massless \
junctions between elastic elements, such as and in particular tips of blade \
springs when these are taken to be massless.\
\>", "Text",
 InitializationCell->True],

Cell["\<\
allfloats::usage = \"allfloats is part of the specification of the model. It \
should be a list of position and angle variables for massless junctions \
between elastic elements.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
allfloats = {
\tql,
\tqr
};\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
The state of the support is defined in terms of \"parameters\" rather than \
\"variables\". These are fixed for the purposes of the normal mode \
calculation, but can have displacement inputs applied.\
\>", "Text",
 InitializationCell->True],

Cell["\<\
allparams::usage = \"allparams is part of the specification of the model. It \
should be a list of the positions and angles describing the state of the \
support structure, plus any other coordinates that are constant for the \
purposes of the normal mode calculation but through which one might want to \
inject a displacement input.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"allparams", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "x00", ",", "y00", ",", "z00", " ", ",", "yaw00", ",", "pitch00", ",", 
     "roll00"}], " ", "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Velocity variables. The kinetic energy is specified initially in terms of \
derivatives of functions of the position variables for convenience, but as \
soon as it's been reduced to derivatives of the position variables directly, \
the calls to the derivative function are removed by substituting these \
velocity variables, because the Lagrangian formulation requires one to take \
derivatives w.r.t. velocities, and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can only differentiate w.r.t. symbols."
}], "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
velocities::usage = \"velocities is a list of symbols (e.g., vx1) for \
velocities corresponding to the variables in allvars (cf., x1).\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
If[!useprecomputed,
\tvelocities = \
Table[ToExpression[\"v\"<>ToString[allvars\[LeftDoubleBracket]i\
\[RightDoubleBracket]]],{i,Length[allvars]}];
    saveprecomputed[\"velocities.m\",velocities],
(*else*)
      getprecomputed[\"velocities.m\"];
];\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Constraint elasticities. These are zero by default but can be set to large \
values for testing purposes, to immobilize particular degrees of freedom.\
\>", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
constraints::usage = \"constraints is a list of elastic constants (e.g., \
kconx1) corresponding to the variables in allvars (cf., x1). They are set to \
zero in defaultvalues but can be overridden with large values for testing \
purposes to immobilize particular degrees of freedom.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
constraints = Table[ToExpression[\"kcon\"<>ToString[allvars\
\[LeftDoubleBracket]i\[RightDoubleBracket]]],{i,Length[allvars]}];\
\>", "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Geometry", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Note:  the z direction is up. The x direction is along the axis of the optic \
and the y direction is transverse.The global origin is midway between the \
points where the wires attach to the suspension structure. \
\>", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Body coordinates for all objects originate at the centre of mass.\
\>", "Text",
 InitializationCell->True],

Cell["\<\
COM = {COMx,COMy,COMz}; usage::COM = \"COM is a local coordinate vector for \
any object, which specifies the centre of mass.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.483120935399*^9, 3.483120942903*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The list of parameters specifying the position and orientation of the support \
structure\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"support", "=", 
   RowBox[{"{", 
    RowBox[{
    "x00", ",", "y00", ",", "z00", ",", "yaw00", ",", "pitch00", ",", 
     "roll00"}], "}"}]}], ";", " ", 
  RowBox[{
   RowBox[{"support", "::", "usage"}], "=", 
   "\"\<support is a list of the parameters specifying the support structure.\
\>\""}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The lists of variables specifying the top blade springs", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bladeL", " ", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"b2s", "[", 
      RowBox[{"support", ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"dyaw1", "/", "2"}], ",", "0"}], "}"}], "+", 
        RowBox[{
         RowBox[{"RotationMatrixXYZBS", "[", 
          RowBox[{"0", ",", "pitchbl", ",", "rollbl"}], "]"}], ".", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "ql"}], "}"}]}]}]}], "]"}], ",", 
     RowBox[{"support", "[", 
      RowBox[{"[", 
       RowBox[{"{", 
        RowBox[{"4", ",", "5", ",", "6"}], "}"}], "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeL", "::", "usage"}], "=", 
   "\"\<bladeL is a list of the variables specifying the upper left blade \
tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeR", " ", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"b2s", "[", 
      RowBox[{"support", ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{
           RowBox[{"-", "dyaw1"}], "/", "2"}], ",", "0"}], "}"}], "+", 
        RowBox[{
         RowBox[{"RotationMatrixXYZBS", "[", 
          RowBox[{"0", ",", "pitchbr", ",", "rollbr"}], "]"}], ".", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "qr"}], "}"}]}]}]}], "]"}], ",", 
     RowBox[{"support", "[", 
      RowBox[{"[", 
       RowBox[{"{", 
        RowBox[{"4", ",", "5", ",", "6"}], "}"}], "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeR", "::", "usage"}], "=", 
   "\"\<bladeR is a list of the variables specifying the right blade \
tip.\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.482519335644717*^9, 3.482519339316083*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The nominal working position of the tips of the blades relative to the \
structure\
\>", "Text",
 InitializationCell->True],

Cell["\<\
bladeLnom={0,dyaw1/2,0};
bladeLnom::usage = \"bladeLnom is the nominal position of the left blade tip \
relative to the structure.\";
bladeRnom={0,-dyaw1/2,0};
bladeRnom::usage = \"bladeRnom is the nominal position of the right blade tip \
relative to the structure.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.482519351343876*^9, 3.482519353400584*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wires from the blade tips lead down to the optic. ", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bladeLa", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeLa", "::", "usage"}], "=", 
   "\"\<bladeLa is the attachment point of the wire on the upper left blade \
tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeRa", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeRa", "::", "usage"}], "=", 
   "\"\<bladeRa is the attachment point of the wire on the upper right blade \
tip.\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.482519763718401*^9, 3.482519765349545*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The list of variables defining the optic.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"optic", "=", 
   RowBox[{"{", 
    RowBox[{
    "x0", ",", "y0", ",", "z0", ",", "yaw0", ",", "pitch0", ",", "roll0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"optic", "::", "usage"}], "=", 
   "\"\<optic is a list of the variables specifying the optic.\>\""}], 
  ";"}]}], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The attachment points for the wires from the structure above", "Text",
 InitializationCell->True],

Cell["\<\
opticl={0,dyaw2/2,dpitch};
opticl::usage=\"opticl is the attachment point of the front left fibre at the \
optic.\";
opticr={0,-dyaw2/2,dpitch};
opticr::usage=\"opticr is the attachment point of the front right fibre at \
the optic.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.482519363895537*^9, 3.482519366207741*^9}, {
   3.483183659524*^9, 3.483183663099*^9}, 3.483183731203*^9, {
   3.48327512484*^9, 3.48327513269*^9}, {3.483279882203*^9, 
   3.483279889064*^9}, {3.48328628029*^9, 3.483286282466*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Items that contribute to the potential energy", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Gravity acting on optic", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["gravlist = {m0 g b2s[optic,COM][[3]]};", "Input",
 InitializationCell->True,
 CellChangeTimes->{3.483286322274*^9},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define wires. ", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Initialize list of wires to zero", "Text",
 InitializationCell->True],

Cell["\<\
wirelist::usage = \"wirelist is part of the specification of the model. It is \
a list of structures defining wires. Each structure containing the following \
items:\\n
{\\n
\tcoordinate list defining first mass,\\n
\tattachment point for first mass (local coordinates),\\n
\tattachment vector for first mass,\\n
\tcoordinate list defining second mass,\\n
\tattachment point for second mass (local coordinates),\\n
\tattachment vector for second mass,\\n
\tYoung's modulus,\\n
\tunstretched length,\\n
\tlongitudinal elasticity,\\n
\tvector defining principal axis 1,\\n
\tmoment of area along principal axis 1,\\n
\tmoment of area along principal axis 2,\\n
\tlinear elasticity type,\\n
\tangular elasticity type\\n
}\";
\t\
\>", "Input",
 InitializationCell->True],

Cell["wirelist={};", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fibres from structure to optic", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
AppendTo[wirelist,{
\tbladeL,
\tbladeLa, 
\tbladelvec,
\toptic,
\topticl,
\topticlvec,
\tY0,
\tul0,
\tkw0,
\t{1,0,0},
\tM01,
\tM02,
\tfibretype,
\tfibreatype
}];
AppendTo[wirelist,{
\tbladeR,
\tbladeRa,
\tbladervec,
\toptic,
\topticr,
\topticrvec,
\tY0,
\tul0,
\tkw0,
\t{1,0,0},
\tM01,
\tM02,
\tfibretype,
\tfibreatype
}];\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Blades", "Text",
 InitializationCell->True],

Cell["springlist = {};", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[springlist, {
\tsupport,
\tbladeLnom,
\t{0,pitchbl,rollbl},
\tbladeL,
\tCOM,
\t{0,pitchbl,rollbl},
\tbladetype,
\t{
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,kbz,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0}
\t},
\t{0,0,bd*kbz,0,0,0}
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[springlist, {
\tsupport,
\tbladeRnom,
\t{0,pitchbr,rollbr},
\tbladeR,
\tCOM,
\t{0,pitchbr,rollbr},
\tbladetype,
\t{
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,kbz,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0}
\t},
\t{0,0,bd*kbz,0,0,0}
}];\
\>", "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The kinetic energy", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["The moment of inertia tensors in body coordinates", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["IM0 = {{I0x, 0, 0}, {0, I0y, 0}, {0, 0, I0z}};\t\t\t(* optic *)", \
"Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IM0::usage = \"IM0 is the MOI tensor for the optic.\";
\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.483272725027*^9, 3.483272725308*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The expression for kinetic energy", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
kinetic::usage = \"kinetic is part of the specification of the model. It \
should be an expression for the kinetic energy in terms of derivatives of the \
variables (e.g., Dt[x1,t]).\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
kinetic = (
\t(1/2) m0 Plus@@(Dt[b2s[optic,COM],t]^2) 
\t+(1/2) omegaB[yaw0, pitch0, roll0].IM0.omegaB[yaw0, pitch0, roll0]
);\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Values of constants", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Default values (converted as closely as from Matlab code by Ken Strain et al, \
plus a bit from Bench) as a huge list of substitutions. Don't hack this list \
unless the new values are pretty definitive. Rather, add overriding \
substitutions to the empty list in the line that looks like \"overrides = {};\
\". at the beginning of the calculation proper. Some of the values in this \
list can be symbolic, but there should be enough numerical ones such that \
when all the dependencies are sorted out (by Recurse[]), everything ends up \
numerical.\
\>", "Text",
 InitializationCell->True],

Cell["\<\
The substitutions below are for the quad pendulum protoype at MIT, with CAD \
data for masses and moments of inertia
\
\>", "Text",
 InitializationCell->True],

Cell["\<\
defaultvalues::usage = \"defaultvalues is part of the specification of the \
model. It should be a list of substitutions for all constants. Some of the \
values can be given symbolically in terms of other constants in the list, but \
there should be enough given numerically that the whole collection becomes \
numeric when Recurse[] is applied.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
defaultvalues = {

 g\t\t-> 9.81,

 tx\t\t-> 0.12,\t\t\t(* thickness of optic *)

 tr\t\t-> 0.14,\t\t\t(* radius of optic *)

 den0\t-> 4000.,\t\t\t(* density (sapphire) *)

 COMx\t-> 0,\t\t\t\t(* Suspended mass COM x cohordinate (in local \
cohordinates) *)
 COMy\t-> 0,\t\t\t\t(* Suspended mass COM y cohordinate (in local \
cohordinates) *)
 COMz\t-> 0,\t\t\t\t(* Suspended mass COM z cohordinate (in local \
cohordinates) *)

 m0\t\t-> den0*N[Pi]*tr^2*tx,\t(* mass of optic *)


 I0x\t-> m0*(tr^2/2),\t\t\t(* moment of inertia (transverse roll) *)

 I0y\t-> m0*(tr^2/4+tx^2/12),\t(* moment of inertia (longitudinal pitch) *)

 I0z\t-> m0*(tr^2/4+tx^2/12),\t(* moment of inertia (yaw) *)

 l0\t-> 0.6,\t    \t\t\t(* wire length (stretched) *)

 nw0\t-> 2,\t\t\t\t(* number of wires *)

 r0\t-> 180.*10^-6,\t\t\t(* radius of wire *)

 Y0\t-> Ysteel,\t\t\t\t(* Youngs Modulus of wire *)

 dpitch\t\t-> 0.001,\t\t(* height of wire break-off above optic local \
coordinate origin *)

 dyaw1 -> dyaw2,   \t\t\t(* y-separation of wires at structure *)
 dyaw2 -> 2*tr,    \t\t\t(* y-separation of wires at optic *)


(* true lengths vertically from attachment point to attactment point etc. *)
(* NOTE this section has been adjusted to remove ambiguity - stretched \
lengths have been used throughout *)

tl0 -> Sqrt[sl0^2 - (dyaw1/2-dyaw2/2)^2],\t(* vertical distance between wire \
attachment points *)

ltotal  ->  tl0,

dpend -> tl0,\t\t\t\t\t\t\t\t(* ??? vertical distance between upper \
suspension point and COM ??? *)

ul0->sl0-m0*g/(nw0*kw0*Cos[ArcSin[(dyaw1/2-dyaw2/2)/sl0]]), (* wire \
unstretched length *)

sl0->l0,\t\t\t\t\t\t\t\t\t(* wire stretched length *)

si0->(dyaw1/2-dyaw2/2)/sl0,\t\t\t\t\t(* sine of wire angle *)
c0->Sqrt[sl0^2-(dyaw1/2-dyaw2/2)^2]/sl0,\t(* cosine of wire angle *)

A0->N[Pi]*r0^2, (* effective average cross-sectional area of fibres *)

kw0->Y0*A0/sl0, (* net longitudinal elasticity of fibres *)

M01-> (1/4) N[Pi] r0^4, (* moment of area of fibre in direction \"1\" *)
M02-> (1/4) N[Pi] r0^4, (* moment of area of fibre in direction \"2\" *)

vertblades->True, (* switch specifiying whether the blades act vertically or \
at right angles to wires *)

pitchbl->0,  (* pitch mounting angle of left blade spring *)
pitchbr->0,  (* pitch mounting angle of right blade spring *)
rollbl->If[vertblades,0,-ArcSin[si0]],  (* roll mounting angle of left blade \
spring *)
rollbr->If[vertblades,0,ArcSin[si0]],  (* roll mounting angle of right blade \
spring *)
kbz -> 300, (* scale roughly from quad: 2400*10/80 *)
bd->If[vertblades,1,1/c0]*(m0/2)*g/kbz,
btx->0.03,\t\t(* display size of blade tip *)
bty->0.03,\t\t(* display size of blade tip *)
btz->0.03,\t\t(* display size of blade tip *)

(* damping stuff *)
temperature      -> ifo[Suspension,Temp],
boltzmann      -> ifo[Constants,kB],

alphasilica-> ifo[Suspension,Silica,Alpha],(* coeff. thermal expansion *)
betasilica-> ifo[Suspension,Silica,dlnEdT], (* temp. dependence Youngs \
modulus *)
rhosilica-> ifo[Suspension,Silica,Rho], (* mass density *)
Csilica-> ifo[Suspension,Silica,C], 
Ksilica-> ifo[Suspension,Silica,K],   (* W/(m kg)       *)
Ysilica    -> ifo[Suspension,Silica,Ey], 
phisilica->2. 10^-8,\t\t\t\t\t\t(* intrinsic/bulk damping *)
phissilica->ifo[Suspension,Silica,Phi], (* surface damping, units of m *)

rhosteel  -> ifo[Suspension,C70Steel,Rho],
Csteel    -> ifo[Suspension,C70Steel,C],
Ksteel    -> ifo[Suspension,C70Steel,K],
Ysteel    -> ifo[Suspension,C70Steel,Ey], 
alphasteel  -> ifo[Suspension,C70Steel,Alpha], 
betasteel   -> ifo[Suspension,C70Steel,dlnEdT], 
phisteel -> ifo[Suspension,C70Steel,Phi], 

rhomarag   -> ifo[Suspension,MaragingSteel,Rho], 
Cmarag     -> ifo[Suspension,MaragingSteel,C], 
Kmarag     -> ifo[Suspension,MaragingSteel,K], 
Ymarag     -> ifo[Suspension,MaragingSteel,Ey],
alphamarag   -> ifo[Suspension,MaragingSteel,Alpha], 
betamarag    -> ifo[Suspension,MaragingSteel,dlnEdT], 
phimarag -> ifo[Suspension,MaragingSteel,Phi],
tmU    -> ifo[Suspension,Stage,4,Blade], (* ?????? *)
tmI    -> ifo[Suspension,Stage,3,Blade],  (* ?????? *)
tmL    -> ifo[Suspension,Stage,2,Blade],  (* ?????? *)

deltablade->Ymarag*alphamarag^2*temperature/(rhomarag*Cmarag), (* cf Bench \
delta_v1 *)
taublade->rhomarag*Cmarag*tmU^2/(Kmarag*N[Pi]^2),
damping[imag,bladetype] -> ((phimarag + \
deltablade*(2*N[Pi]*#1*taublade)/(1+(2*N[Pi]*#1*taublade)^2))&),

magicnumber->7.32 10^-2,
deltafibre->Ysilica*temperature*(alphasilica-betasilica*g*(m0)/(nw0*N[Pi]*r0^\
2*Ysilica))^2/(rhosilica*Csilica), 
tausilica->magicnumber*rhosilica*Csilica*4*(N[Pi]*r0^2)/N[Pi], (* cf Bench \
tau_si *)
damping[imag,fibretype] -> ((phisilica + phissilica/r0/2)&),
damping[imag,fibreatype] -> ((phisilica + phissilica/r0 + \
deltafibre*(2*N[Pi]*#1*tausilica)/(1+(2*N[Pi]*#1*tausilica)^2))&),
x00->0,
y00->0,
z00->0,
yaw00->0,
pitch00->0,
roll00->0,
Sequence@@(Replace[constraints,x_:>(x->0),1]) (* generates and splices in \
substitutions of form kconx1->0 *)
};\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.482665696971368*^9, 3.482665734280368*^9}, {
   3.483182676959*^9, 3.483182781097*^9}, {3.483286410885*^9, 
   3.483286474145*^9}, {3.483286505977*^9, 3.4832865347469997`*^9}, {
   3.483286722689*^9, 3.483286802388*^9}, {3.4832868699379997`*^9, 
   3.4832868985880003`*^9}, 3.483287381208*^9, {3.4832879461099997`*^9, 
   3.4832879683570004`*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Usage tags for all the constants", "Text",
 InitializationCell->True],

Cell["\<\
g::usage = \"g is local gravity.\";

tx::usage = \"ux is thickness of optic.\";\t
tr::usage = \"uy is radius of optic.\";\t
den0::usage = \"den0 is density of optic.\";
m0::usage = \"m0 is mass of optic.\";
I0x::usage = \"I0x is x-axis MOI of optic.\";
I0y::usage = \"I0y is y-axis MOI of optic.\";
I0z::usage = \"I0z is z-axis MOI of optic.\";

l0::usage = \"l0 is part of the specification of the model and represents the \
stretched wire (fibre) length from structure to optic.\";

ul0::usage = \"ul0 is unstretched wire (fibre) length from structure to \
optic.\";

sl3::usage = \"sl0 is stretched wire (fibre) length from structure to optic.\";

si0::usage = \"si0 is sine of angle of fibres.\";

c0::usage = \"c0 is cosine of angle of fibres.\";

nw0::usage = \"nw0 is number of wires (fibres) from structure to optic.\";

r0::usage = \"r0 is radius of wires (fibres) from structure to optic.\";

Y0::usage = \"Y0 is Young's modulus of wires (fibres) from structure to \
optic.\";

dpitch::usage = \"dpitch is the height of the wire attachment points above \
the center (not COM) of the optic.\";
dyaw1::usage = \"dyaw1 is the y-direction separation of the wire attachment \
points at the structure.\";
dyaw2::usage = \"dyaw2 is the y-direction separation of the wire attachment \
points at the optic.\";
dx::usage = \"dx is the x-direction separation of the wires.\";

tl0::usage = \"tl0 is the vertical distance from structure attachment point \
to the COM of the optic.\";

ltotal::usage = \"ltotal is the vertical distance from the structure \
attachement point to the COM of the optic.\";

A0::usage = \"A0 is effective average cross-sectional area of wires (fibres) \
from structure to optic for the purposes of calculating the longitudinal \
elasticity.\";

kw0::usage = \"kw0 is net longitudinal elasticity of wires (fibres) from \
structure to optic.\";

M01::usage = \"M31 is the moment of area of wires (fibres) from structure to \
optic in direction \\\"1\\\"\";
M02::usage = \"M32 is the moment of area of wires (fibres) from structure to \
optic in direction \\\"2\\\"\";

(* damping stuff *)

damping::usage = \"damping[imag,dampingtype] is a Mathematica pure function \
giving the frequency dependence of the imaginary (i.e., lossy) part of any \
potential terms tagged with symbol dampingtype. It defaults to 0& but can be \
given a value via a substitution in defaultvalues. damping[real,dampingtype] \
is the corresponding real (i.e., elastic) multiplier. It defaults to 1&.\";

temperature::usage = \"temperature is, well, guess.\";

alphasilica::usage = \"alphasilica is the coefficient of thermal expansion \
for silica.\";
betasilica::usage = \"betasilica is the temperature dependence of Young's \
modulus for silica.\";
rhosilica::usage = \"rhosilica is the density for silica.\";
Csilica::usage = \"Csilica is the heat capacity for silica.\";
Ksilica::usage = \"Ksilica is the bulk modulus for silica.\";
Ysilica::usage = \"Ysilica is the Young's modulus for silica.\";
phisilica::usage = \"phisilica is the bulk loss angle for silica.\";
phissilica::usage = \"phissilica is the surface loss angle (units of m) for \
silica.\";

alphasteel::usage = \"alphasteel is the coefficient of thermal expansion for \
C70 steel.\";
betasteel::usage = \"betasteel is the temperature dependence of Young's \
modulus for C70 steel.\";
rhosteel::usage = \"rhosteel is the density for C70 steel.\";
Csteel::usage = \"Csteel is the heat capacity for C70 steel.\";
Ksteel::usage = \"Ksteel is the bulk modulus for C70 steel.\";
Ysteel::usage = \"Ysteel is the Young's modulus for C70 steel.\";
phisteel::usage = \"phisteel is the bulk loss angle for C70 steel.\";

alphamarag::usage = \"alphamarag is the coefficient of thermal expansion for \
maraging steel.\";
betamarag::usage = \"betamarag is the temperature dependence of Young's \
modulus for maraging steel.\";
rhomarag::usage = \"rhomarag is the density for maraging steel.\";
Cmarag::usage = \"Cmarag is the heat capacity for maraging steel.\";
Kmarag::usage = \"Kmarag is the bulk modulus for maraging steel.\";
Ymarag::usage = \"Ymarag is the Young's modulus for maraging steel.\";
phimarag::usage = \"phimarag is the bulk loss angle for maraging steel.\";

magicnumber::usage = \"magicnumber is a geometrical factor for thermoelastic \
damping.\";
deltafibre::usage = \"deltafibre is the thermoelastic damping parameter delta \
for the wires from mass I to the optic.\";
tausilica::usage = \"tausilica is the thermoelastic damping parameter tau for \
the wires from mass I to the optic.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.483287453342*^9, 3.4832874572320004`*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initial position (nominal)", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Default values of the parameters (i.e., the nominal position of the structure)\
\>", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
initparam::usage = \"initparam is part of the specification of the model. It \
should give a list of substitutions for the nominal values of all the \
parameters in allparams. The values can be given symbolically in terms of \
constants defined in the list defaultvalues.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
initparam = {
\tx00->0,
\ty00->0,
\tz00->0,
\tyaw00->0,
\tpitch00->0,
\troll00->0
};\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Approximate starting values for finding the minimum of the potential. The \
stretch of the wires has been anticipated in these values and a vertical \
pre-stress has been applied to the blades in the model itself, so the only \
sag that should show up relative to them is due to longitudinal stretching of \
the blades (which cross-couples to vertical via the diagonal wires).\
\>", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
startpos::usage = \"startpos is part of the specification of the model. It \
should be a list of approximate values of all variables to be used as a \
starting point for minimizing the potential. The values can be given \
symbolically in terms of constants defined in the list defaultvalues.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
startpos = {
\tql->0,
\tqr->0,
\tx0->0,
\ty0->0,
\tz0->z00-tl0-dpitch,
\tyaw0->0,
\tpitch0->0,
\troll0->0
};\
\>", "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model-specific utilities", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["A switch variable to turn graphics on and off", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["doplots = True;", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
doplots::usage = \"doplots is a switch that enables plotting when set to True\
\";\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Some matrices to postprocess the angular displacement elements in a \
eigenvector into a more convenient basis\
\>", "Text",
 InitializationCell->True],

Cell["\<\
e2b::usage = \"e2b is a matrix that converts the angular displacement \
elements of an eigenvector from differential yaw/pitch/roll format to body \
coordinates.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2b := DiagonalBlockMatrix[{
\tIdentityMatrix[3],
\tomegaIB[yaw0,pitch0,roll0]
}]/.optval; \
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2s::usage = \"e2s is a matrix that converts the angular displacement \
elements of an eigenvector from differential yaw/pitch/roll format to body \
coordinates.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2s := DiagonalBlockMatrix[{
\tIdentityMatrix[3],
\tomegaIS[yaw0,pitch0,roll0]
}]/.optval; \
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2i::usage = \"e2i is a matrix that converts the angular displacement \
elements of an eigenvector from differential yaw/pitch/roll format to \
\\\"independent\\\" yaw/pitch/roll format, i.e., in terms of new yaw, pitch \
and roll variables defined so that the equilibrium position is \
yawnew=pitchnew=rollnew=0.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2ni := DiagonalBlockMatrix[{
\tIdentityMatrix[3],
\tomegaSNI.omegaIS[yaw0,pitch0,roll0]
}]/.optval; \
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Some vectors representing various interesting excitation inputs\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportxinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "x00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportxinput::usage = \"supportxinput is a vector representing excitation of \
the support in x.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportyinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "y00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportyinput::usage = \"supportyinput is a vector representing excitation of \
the support in y.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportzinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "z00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportzinput::usage = \"supportzinput is a vector representing excitation of \
the support in z.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportyawinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "yaw00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportyawinput::usage = \"supportyawinput is a vector representing \
excitation of the support in yaw.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportpitchinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "pitch00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportpitchinput::usage = \"supportpitchinput is a vector representing \
excitation of the support in pitch.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportrollinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "roll00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportrollinput::usage = \"supportrollinput is a vector representing \
excitation of the support in roll.\";\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Some vectors for selecting various interesting excitation outputs\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticxoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "x0", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticyoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "y0", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticzoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "z0", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticyawoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "yaw0", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticpitchoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "pitch0", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticrolloutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "roll0", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticindyawoutput", " ", ":=", " ", 
   RowBox[{
    RowBox[{"makeoutputvector", "[", "yaw0", "]"}], ".", "e2i"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticindpitchoutput", " ", ":=", " ", 
   RowBox[{
    RowBox[{"makeoutputvector", "[", "pitch0", "]"}], ".", "e2i"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticindrolloutput", " ", ":=", " ", 
   RowBox[{
    RowBox[{"makeoutputvector", "[", "roll0", "]"}], ".", "e2i"}]}], 
  ";"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Utilities to do plots of the mode shapes", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Various interesting groups of points, as 3D graphics", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
maxx:=Max[tx];
maxy:=Max[dyaw2/2];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
ztop:=z00/.constval;
zbottom:=z00-tl0-dpitch-tr/.constval;\
\>", "Input",
 InitializationCell->True],

Cell["\<\
If[True,
\tsupportpoints[sub_] := {
\t\tGraphics3D[Point[support/.constval/.sub]]
\t};
\treferencemarkers := {
\t\tGraphics3D[Point[{+maxx/2,+maxy/2, ztop}/.constval]],
\t\tGraphics3D[Point[{+maxx/2,-maxy/2, ztop}/.constval]],
\t\tGraphics3D[Point[{-maxx/2,+maxy/2, ztop}/.constval]],
\t\tGraphics3D[Point[{-maxx/2,-maxy/2, ztop}/.constval]],
\t\tGraphics3D[Point[{+maxx/2,+maxy/2, zbottom}/.constval]],
\t\tGraphics3D[Point[{+maxx/2,-maxy/2, zbottom}/.constval]],
\t\tGraphics3D[Point[{-maxx/2,+maxy/2, zbottom}/.constval]],
\t\tGraphics3D[Point[{-maxx/2,-maxy/2, zbottom}/.constval]]
\t};
];\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Various interesting groups of lines, as 3D graphics", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[True,
\twires[sub_] := {
\t\tGraphics3D[
\t\t\tLine[
\t\t\t\t{
\t\t\t\t\tb2s[wirelist[[1,w$obj1]],wirelist[[1,w$pos1]]],
\t\t\t\t\tb2s[wirelist[[1,w$obj2]],wirelist[[1,w$pos2]]]
\t\t\t\t}/.constval/.sub
\t\t\t]
\t\t],
\t\tGraphics3D[
\t\t\tLine[
\t\t\t\t{
\t\t\t\t\tb2s[wirelist[[2,w$obj1]],wirelist[[2,w$pos1]]],
\t\t\t\t\tb2s[wirelist[[2,w$obj2]],wirelist[[2,w$pos2]]]
\t\t\t\t}/.constval/.sub
\t\t\t]
\t\t]
\t}
];
\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Various interesting solids, as 3D graphics", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tbladeLoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyCuboid[
\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t]
\t\t\t],
\t\t\t0, 0, 0
\t\t],
\t\tbladeL[[{1,2,3}]]
\t]/.constval/.sub,
(* else v6+ *)
\tbladeLoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[\t\t
\t\t\t\t\t\tCuboid[
\t\t\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\t0, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\t0, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\t0, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tbladeL[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.388856685791905*^9, 3.388861247156967*^9, {3.388861391298101*^9, 
   3.388861433064266*^9}, {3.388861701226256*^9, 3.388861702758912*^9}, {
   3.388861737929062*^9, 3.3888617558747787`*^9}, {3.388861826850439*^9, 
   3.388861946483223*^9}, {3.388862041483224*^9, 3.3888620638873243`*^9}, 
   3.388862129681826*^9, {3.39073277934309*^9, 3.390732830229669*^9}, {
   3.467661881461638*^9, 3.467661888237212*^9}, {3.482519730954228*^9, 
   3.48251973392237*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tbladeRoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyCuboid[
\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t]
\t\t\t],
\t\t\t0, 0, 0
\t\t],
\t\tbladeR[[{1,2,3}]]
\t]/.constval/.sub,
(* else v6+ *)
\tbladeRoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tCuboid[
\t\t\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\t0, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\t0, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\t0, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tbladeR[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.3888566866191072`*^9, 3.388861246317478*^9, 3.388862101636524*^9, {
   3.388862134745468*^9, 3.388862140981388*^9}, {3.3907327098849897`*^9, 
   3.39073276422757*^9}, {3.390732886757392*^9, 3.390732931792983*^9}, 
   3.3907330767402887`*^9, {3.467661866191394*^9, 3.467661876205659*^9}, {
   3.482519755365177*^9, 3.482519758222484*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
If[$VersionNumber<6.,
\topticoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tRotateShapeXYZ[
\t\t\t\tGraphics3D[
\t\t\t\t\tMyOpenCylinder5[
\t\t\t\t\t\ttr,{-tx/2,tx/2},20
\t\t\t\t\t]
\t\t\t\t],
\t\t\t\t0, Pi/2, 0
\t\t\t],
\t\t\tyaw0, pitch0, roll0
\t\t],
\t\t{x0, y0, z0}
\t]/.constval/.sub,
(* else v6+ *)
\topticoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tRotate[
\t\t\t\t\t\t\tMyOpenCylinder[
\t\t\t\t\t\t\t\ttr,{-tx/2,tx/2},20
\t\t\t\t\t\t\t],
\t\t\t\t\t\t\tPi/2, {0,1,0}, {0,0,0}
\t\t\t\t\t\t],
\t\t\t\t\t\troll0, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\tpitch0, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\tyaw0, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\toptic[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.38885669186707*^9, 3.3888612468490458`*^9, 3.38886224716494*^9, {
   3.390733468720807*^9, 3.390733487854968*^9}, {3.390733546023054*^9, 
   3.3907335509369707`*^9}, {3.3907335856093903`*^9, 3.390733608038183*^9}, {
   3.390733688257399*^9, 3.390733691041258*^9}, {3.390740581388052*^9, 
   3.390740637230397*^9}, 3.3907408437196903`*^9, 3.390740985314378*^9, {
   3.390741588982959*^9, 3.390741613475223*^9}, {3.390741659511055*^9, 
   3.390741659526108*^9}, 3.390741692892099*^9, 3.3908100809141693`*^9, 
   3.393433077436898*^9, {3.393433382780921*^9, 3.3934333971539392`*^9}, {
   3.482519863625226*^9, 3.4825198711058187`*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["A function to plot an eigenmode", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
eigenplot::usage = \"eigenplot[e, f, {x, y, z},fm] makes a plot of the \
eigenvector e, scaled by a factor f, with viewpoint {x,y,z}.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
eigenplot[e_, ff_, {x_, y_, z_}, fm_] := If[
\tdoplots,
\tBlock[
\t\t{s=tosub[ff e,fm]},
\t\tShow[
\t\t\treferencemarkers,
\t\t\twires[s],
\t\t\t(*opticpoints[s],*)
\t\t\t(*supportpoints[s],*)
\t\t\tbladeLoutline[s],
\t\t\tbladeRoutline[s],
\t\t\topticoutline[s],
\t\t\tViewPoint->{x, y, z},
\t\t\tPlotRange->{{-1.5 maxx,1.5 maxx},{-1.5 maxy,1.5 \
maxy},{zbottom-0.1,ztop}}/.constval
\t\t]
\t],
\tPrint[\"Plots switched off (doplots = False)\"]
]\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A pretty-printing routine for the eigenvectors in the x/y/z/yaw/pitch/roll \
basis\
\>", "Text",
 InitializationCell->True],

Cell["\<\
pad::usage = \"pad[ev] takes an eigenvector and inserts dummy values where \
angle variables had been suppressed, so as to make even groups of six.\";\
\>", "Input",
 InitializationCell->True],

Cell["pad[e_]:=Partition[e,6] ", "Input",
 InitializationCell->True],

Cell["\<\
pretty::usage = \"pretty[ev] prints an eigenvector in a pretty table format \
with headings.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"pretty", "[", "e_", "]"}], " ", ":=", " ", 
  RowBox[{"TableForm", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<\>\"", ",", "\"\<optic\>\""}], "}"}], "}"}], ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
           "\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\"", ",", 
            "\"\<yaw\>\"", ",", "\"\<pitch\>\"", ",", "\"\<roll\>\""}], "}"}],
           "}"}], ",", 
         RowBox[{"pad", "[", "e", "]"}]}], "]"}], "]"}]}], "]"}], "]"}], 
   "]"}], " "}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"pretty", "[", 
   RowBox[{"h_", ",", "e_"}], "]"}], " ", ":=", 
  RowBox[{"Chop", "[", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
       "\"\<f\>\"", ",", "\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\"", 
        ",", "\"\<yaw\>\"", ",", "\"\<pitch\>\"", ",", "\"\<roll\>\""}], 
       "}"}], "}"}], ",", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", "h", "}"}], ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{"pad", "[", "e", "]"}], "]"}]}], "]"}], "]"}]}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions to classify eigenvectors", "Text",
 InitializationCell->True],

Cell["\<\
longpitchQ[e_] := Block[
\t{s=ToString[important[e][[1]]]},
\tStringPosition[s,\"pitch\"]=={{1,5}}
\t||StringPosition[s,\"x\"]=={{1,1}}
]

transrollQ[e_] := Block[
\t{s=ToString[important[e][[1]]]},
\t(
\t\tStringPosition[s,\"y\"]=={{1,1}}
\t\t&&StringPosition[s,\"yaw\"]=={}
\t)
\t||StringPosition[s,\"roll\"]=={{1,4}}
]

yawQ[e_] := Block[
\t{s=ToString[important[e][[1]]]},
\tStringPosition[s,\"yaw\"]=={{1,3}}
]

vertQ[e_] := Block[
\t{s=ToString[important[e][[1]]]},
\tStringPosition[s,\"z\"]=={{1,1}}
]\
\>", "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->"RulerBar",
CellGrouping->Manual,
WindowSize->{944, 534},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 123, 2, 71, "Section",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[715, 28, 64, 1, 36, "Subsection",
 InitializationCell->True],
Cell[782, 31, 221, 5, 31, "Input",
 InitializationCell->True],
Cell[1006, 38, 235, 6, 48, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[1256, 47, 146, 2, 29, "Text",
 InitializationCell->True],
Cell[1405, 51, 358, 7, 29, "Text",
 InitializationCell->True],
Cell[1766, 60, 543, 11, 83, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2334, 75, 61, 1, 36, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2420, 80, 64, 1, 27, "Subsubsection",
 InitializationCell->True],
Cell[2487, 83, 1370, 44, 137, "Text",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[3894, 132, 57, 1, 27, "Subsubsection",
 InitializationCell->True],
Cell[3954, 135, 1181, 22, 155, "Text",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5184, 163, 62, 1, 36, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[5271, 168, 142, 4, 29, "Text",
 InitializationCell->True],
Cell[5416, 174, 177, 5, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[5630, 184, 87, 2, 29, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[5742, 190, 33, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[5800, 194, 91, 1, 29, "Text",
 InitializationCell->True],
Cell[5894, 197, 194, 3, 31, "Input",
 InitializationCell->True],
Cell[6091, 202, 292, 5, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[6398, 210, 195, 3, 31, "Input",
 InitializationCell->True],
Cell[6596, 215, 116, 3, 29, "Text",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[6739, 222, 289, 6, 31, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[7053, 232, 31, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[7109, 236, 114, 3, 29, "Text",
 InitializationCell->True],
Cell[7226, 241, 105, 2, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[7368, 248, 80, 1, 29, "Text",
 InitializationCell->True],
Cell[7451, 251, 69, 1, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[7557, 257, 82, 1, 29, "Text",
 InitializationCell->True],
Cell[7642, 260, 69, 1, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[7748, 266, 64, 1, 29, "Text",
 InitializationCell->True],
Cell[7815, 269, 65, 1, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[7917, 275, 54, 1, 29, "Text",
 InitializationCell->True],
Cell[7974, 278, 65, 1, 31, "Input",
 InitializationCell->True],
Cell[8042, 281, 244, 5, 31, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8359, 294, 65, 1, 36, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[8449, 299, 67, 1, 29, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[8541, 304, 346, 6, 47, "Text",
 InitializationCell->True],
Cell[8890, 312, 280, 6, 31, "Input",
 InitializationCell->True],
Cell[9173, 320, 127, 6, 65, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[9315, 329, 249, 5, 47, "Text",
 InitializationCell->True],
Cell[9567, 336, 233, 5, 31, "Input",
 InitializationCell->True],
Cell[9803, 343, 111, 7, 82, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[9939, 354, 251, 5, 47, "Text",
 InitializationCell->True],
Cell[10193, 361, 389, 7, 31, "Input",
 InitializationCell->True],
Cell[10585, 370, 289, 7, 72, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[10911, 382, 601, 12, 65, "Text",
 InitializationCell->True],
Cell[11515, 396, 190, 4, 31, "Input",
 InitializationCell->True],
Cell[11708, 402, 333, 11, 116, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[12078, 418, 233, 5, 29, "Text",
 InitializationCell->True],
Cell[12314, 425, 338, 6, 31, "Input",
 InitializationCell->True],
Cell[12655, 433, 179, 4, 31, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12883, 443, 83, 2, 29, "Text",
 InitializationCell->True],
Cell[12969, 447, 297, 6, 47, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[13291, 457, 116, 3, 29, "Text",
 InitializationCell->True],
Cell[13410, 462, 240, 5, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[13687, 472, 140, 4, 29, "Text",
 InitializationCell->True],
Cell[13830, 478, 376, 11, 52, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[14243, 494, 98, 1, 29, "Text",
 InitializationCell->True],
Cell[14344, 497, 1842, 53, 112, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[16223, 555, 133, 4, 29, "Text",
 InitializationCell->True],
Cell[16359, 561, 387, 9, 82, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[16783, 575, 93, 1, 29, "Text",
 InitializationCell->True],
Cell[16879, 578, 783, 22, 92, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[17699, 605, 84, 1, 29, "Text",
 InitializationCell->True],
Cell[17786, 608, 383, 12, 52, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[18206, 625, 103, 1, 29, "Text",
 InitializationCell->True],
Cell[18312, 628, 573, 13, 82, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18934, 647, 88, 1, 29, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[19047, 652, 98, 2, 29, "Text",
 InitializationCell->True],
Cell[19148, 656, 153, 3, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[19338, 664, 57, 1, 29, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[19420, 669, 75, 1, 29, "Text",
 InitializationCell->True],
Cell[19498, 672, 776, 22, 320, "Input",
 InitializationCell->True],
Cell[20277, 696, 56, 1, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[20370, 702, 105, 2, 29, "Text",
 InitializationCell->True],
Cell[20478, 706, 406, 35, 558, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20933, 747, 49, 1, 29, "Text",
 InitializationCell->True],
Cell[20985, 750, 60, 1, 31, "Input",
 InitializationCell->True],
Cell[21048, 753, 321, 20, 320, "Input",
 InitializationCell->True],
Cell[21372, 775, 321, 20, 320, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21742, 801, 93, 2, 29, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[21860, 807, 124, 2, 29, "Text",
 InitializationCell->True],
Cell[21987, 811, 141, 3, 31, "Input",
 InitializationCell->True],
Cell[22131, 816, 167, 5, 48, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[22335, 826, 108, 2, 29, "Text",
 InitializationCell->True],
Cell[22446, 830, 237, 5, 31, "Input",
 InitializationCell->True],
Cell[22686, 837, 210, 7, 82, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22945, 850, 94, 2, 29, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[23064, 856, 600, 10, 83, "Text",
 InitializationCell->True],
Cell[23667, 868, 168, 5, 47, "Text",
 InitializationCell->True],
Cell[23838, 875, 400, 7, 31, "Input",
 InitializationCell->True],
Cell[24241, 884, 5426, 148, 2071, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[29704, 1037, 75, 1, 29, "Text",
 InitializationCell->True],
Cell[29782, 1040, 4715, 107, 1306, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34546, 1153, 69, 1, 29, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[34640, 1158, 161, 4, 29, "Text",
 InitializationCell->True],
Cell[34804, 1164, 326, 6, 31, "Input",
 InitializationCell->True],
Cell[35133, 1172, 168, 11, 150, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[35338, 1188, 459, 8, 65, "Text",
 InitializationCell->True],
Cell[35800, 1198, 346, 6, 31, "Input",
 InitializationCell->True],
Cell[36149, 1206, 160, 12, 184, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36370, 1225, 73, 1, 36, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[36468, 1230, 120, 2, 29, "Text",
 InitializationCell->True],
Cell[36591, 1234, 91, 2, 31, "Input",
 InitializationCell->True],
Cell[36685, 1238, 134, 4, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[36856, 1247, 161, 4, 29, "Text",
 InitializationCell->True],
Cell[37020, 1253, 216, 5, 31, "Input",
 InitializationCell->True],
Cell[37239, 1260, 143, 6, 82, "Input",
 InitializationCell->True],
Cell[37385, 1268, 216, 5, 31, "Input",
 InitializationCell->True],
Cell[37604, 1275, 143, 6, 82, "Input",
 InitializationCell->True],
Cell[37750, 1283, 368, 7, 31, "Input",
 InitializationCell->True],
Cell[38121, 1292, 153, 6, 82, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[38311, 1303, 114, 3, 29, "Text",
 InitializationCell->True],
Cell[38428, 1308, 161, 4, 31, "Input",
 InitializationCell->True],
Cell[38592, 1314, 152, 4, 31, "Input",
 InitializationCell->True],
Cell[38747, 1320, 161, 4, 31, "Input",
 InitializationCell->True],
Cell[38911, 1326, 152, 4, 31, "Input",
 InitializationCell->True],
Cell[39066, 1332, 161, 4, 31, "Input",
 InitializationCell->True],
Cell[39230, 1338, 152, 4, 31, "Input",
 InitializationCell->True],
Cell[39385, 1344, 165, 4, 31, "Input",
 InitializationCell->True],
Cell[39553, 1350, 158, 4, 31, "Input",
 InitializationCell->True],
Cell[39714, 1356, 169, 4, 31, "Input",
 InitializationCell->True],
Cell[39886, 1362, 164, 4, 31, "Input",
 InitializationCell->True],
Cell[40053, 1368, 167, 4, 31, "Input",
 InitializationCell->True],
Cell[40223, 1374, 161, 4, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[40421, 1383, 116, 3, 29, "Text",
 InitializationCell->True],
Cell[40540, 1388, 160, 4, 31, "Input",
 InitializationCell->True],
Cell[40703, 1394, 160, 4, 31, "Input",
 InitializationCell->True],
Cell[40866, 1400, 160, 4, 31, "Input",
 InitializationCell->True],
Cell[41029, 1406, 164, 4, 31, "Input",
 InitializationCell->True],
Cell[41196, 1412, 168, 4, 31, "Input",
 InitializationCell->True],
Cell[41367, 1418, 166, 4, 31, "Input",
 InitializationCell->True],
Cell[41536, 1424, 198, 6, 31, "Input",
 InitializationCell->True],
Cell[41737, 1432, 202, 6, 31, "Input",
 InitializationCell->True],
Cell[41942, 1440, 200, 6, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[42179, 1451, 115, 2, 29, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[42319, 1457, 127, 2, 29, "Text",
 InitializationCell->True],
Cell[42449, 1461, 86, 4, 48, "Input",
 InitializationCell->True],
Cell[42538, 1467, 110, 4, 48, "Input",
 InitializationCell->True],
Cell[42651, 1473, 677, 18, 269, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[43365, 1496, 126, 2, 29, "Text",
 InitializationCell->True],
Cell[43494, 1500, 504, 24, 371, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[44035, 1529, 117, 2, 29, "Text",
 InitializationCell->True],
Cell[44155, 1533, 1206, 42, 541, "Input",
 InitializationCell->True],
Cell[45364, 1577, 1081, 40, 541, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[46460, 1620, 1497, 50, 643, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[47982, 1674, 106, 2, 29, "Text",
 InitializationCell->True],
Cell[48091, 1678, 188, 4, 31, "Input",
 InitializationCell->True],
Cell[48282, 1684, 530, 22, 320, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48861, 1712, 133, 4, 29, "Text",
 InitializationCell->True],
Cell[48997, 1718, 202, 4, 31, "Input",
 InitializationCell->True],
Cell[49202, 1724, 68, 1, 31, "Input",
 InitializationCell->True],
Cell[49273, 1727, 147, 4, 31, "Input",
 InitializationCell->True],
Cell[49423, 1733, 733, 21, 52, "Input",
 InitializationCell->True],
Cell[50159, 1756, 669, 20, 31, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[50865, 1781, 77, 1, 29, "Text",
 InitializationCell->True],
Cell[50945, 1784, 560, 26, 422, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
